pub struct GlobalLockedSkillEntry {Show 14 fields
pub id: String,
pub name: String,
pub version: String,
pub source: SkillSource,
pub source_name: Option<String>,
pub source_url: Option<String>,
pub source_branch: Option<String>,
pub commit_hash: Option<String>,
pub checksum: Option<String>,
pub dependencies: Vec<String>,
pub groups: Vec<String>,
pub installed_at: DateTime<Utc>,
pub last_checked_at: Option<DateTime<Utc>>,
pub last_updated_at: Option<DateTime<Utc>>,
}Expand description
A single entry in the global lock with operational timestamps.
Fields
id: Stringname: Stringversion: Stringsource: SkillSourcesource_name: Option<String>source_url: Option<String>source_branch: Option<String>commit_hash: Option<String>checksum: Option<String>dependencies: Vec<String>groups: Vec<String>installed_at: DateTime<Utc>last_checked_at: Option<DateTime<Utc>>last_updated_at: Option<DateTime<Utc>>Trait Implementations
Sourceimpl Clone for GlobalLockedSkillEntry
impl Clone for GlobalLockedSkillEntry
Sourcefn clone(&self) -> GlobalLockedSkillEntry
fn clone(&self) -> GlobalLockedSkillEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GlobalLockedSkillEntry
impl Debug for GlobalLockedSkillEntry
Sourceimpl<'de> Deserialize<'de> for GlobalLockedSkillEntry
impl<'de> Deserialize<'de> for GlobalLockedSkillEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GlobalLockedSkillEntry
impl PartialEq for GlobalLockedSkillEntry
Sourcefn eq(&self, other: &GlobalLockedSkillEntry) -> bool
fn eq(&self, other: &GlobalLockedSkillEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GlobalLockedSkillEntry
impl Serialize for GlobalLockedSkillEntry
impl StructuralPartialEq for GlobalLockedSkillEntry