Output formatting module providing consistent formatting across commands
This module provides shared output formatting capabilities that can be used by multiple CLI commands to ensure consistent output styling.
Structs
- ListRow
- One row for the list table: union of all skills with presence and gap flags.
Enums
- Output
Format - Supported output formats
Functions
- escape_
xml - Escape XML special characters
- format_
list_ results - Format list results in the specified output format
- format_
search_ results - Format search results in the specified output format
- format_
show_ results - Format show results in the specified output format