pub fn validate_path_component(
component: &str,
) -> Result<String, PathSecurityError>Expand description
Validate and sanitize a user-provided path component Returns an error if the component contains path traversal attempts
pub fn validate_path_component(
component: &str,
) -> Result<String, PathSecurityError>Validate and sanitize a user-provided path component Returns an error if the component contains path traversal attempts