validate_cloned_skill

Function validate_cloned_skill 

pub fn validate_cloned_skill(
    cloned_path: &Path,
) -> Result<PathBuf, ServiceError>
Validate that a cloned repository contains a valid skill structure.

A valid skill structure must contain a SKILL.md file either at the repository root or in a subdirectory.

Arguments

  • cloned_path - Path to the cloned repository directory

Returns

Returns the path to the directory containing SKILL.md (may be a subdirectory).

Errors

Returns ServiceError::Validation if SKILL.md is not found in the repository.

Examples

use fastskill::storage::git::validate_cloned_skill;
use std::path::Path;

let skill_path = validate_cloned_skill(Path::new("/path/to/cloned/repo"))?;
// skill_path points to directory containing SKILL.md