pub struct ZipHandler;Implementations
Sourceimpl ZipHandler
impl ZipHandler
pub fn new() -> Result<Self, ServiceError>
Sourcepub async fn validate_package(
&self,
_zip_path: &Path,
) -> Result<(), ServiceError>
pub async fn validate_package( &self, _zip_path: &Path, ) -> Result<(), ServiceError>
Validate ZIP package structure
Sourcepub fn extract_to_dir(
&self,
zip_path: &Path,
dest_dir: &Path,
) -> Result<(), ServiceError>
pub fn extract_to_dir( &self, zip_path: &Path, dest_dir: &Path, ) -> Result<(), ServiceError>
Safely extract a ZIP file to a destination directory
This function protects against ZIP slip attacks by:
- Normalizing the output path for each entry
- Verifying that the normalized path stays within the extraction directory
- Rejecting entries that would create files outside the extraction root
- Rejecting symlink entries
Arguments
zip_path- Path to the ZIP file to extractdest_dir- Destination directory for extraction (must exist)
Errors
Returns ServiceError::Io for I/O errors
Returns ServiceError::Validation if path traversal is detected