Module output

Module output 

Output formatting module providing consistent formatting across commands

This module provides shared output formatting capabilities that can be used by multiple CLI commands to ensure consistent output styling.

Structs

ListRow
One row for the list table: union of all skills with presence and gap flags.

Enums

OutputFormat
Supported output formats

Functions

escape_xml
Escape XML special characters
format_list_results
Format list results in the specified output format
format_search_results
Format search results in the specified output format
format_show_results
Format show results in the specified output format