Git operations for cloning skill repositories using system git binary
Enums
- GitError
- Git operation error types
Functions
- checkout_
branch_ or_ tag - Checkout a specific branch or tag in a git repository.
- clone_
repository - Clone a git repository to a temporary directory.
- validate_
cloned_ skill - Validate that a cloned repository contains a valid skill structure.